==> xlniuxdata-vipgame-1.0.0-20141225.035105-5-sources.jar: com/xunlei/niux/data/vipgame/vo/GameServers.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;

/**
 * 游戏服务器（分区）
 * @author lin
 * @date 2012-9-12
 * @Descripter:
 */
@Table(tableName="gameservers",pkFieldName="seqId",pkFieldAssign=false)
public class GameServers {
	private Long seqId;
	private String gameId;
	private Integer fenQuNum;
	private String fenQuName;
	private String serverId;
	private String serverName;
	private String openStatus;
	private String openTime;
	private String remark;
	private String inputBy;
	private String inputTime;
	private String editBy;
	private String editTime;
	private String address;
	private Boolean redtitle;
	private Boolean isnew;
	private Boolean isrecommand;
	private String fenQuNickName;
	private String bigFenQuName;
	@Column(columnName="openTime",isWhereColumn=true,operator=Operator.GE)
	private String fromopentime;
	@Column(columnName="openTime",isWhereColumn=true,operator=Operator.LT)
	private String toopentime;
	
	public String getBigFenQuName() {
		return bigFenQuName;
	}
	public void setBigFenQuName(String bigFenQuName) {
		this.bigFenQuName = bigFenQuName;
	}
	public Boolean getRedtitle() {
		return redtitle;
	}
	public void setRedtitle(Boolean redtitle) {
		this.redtitle = redtitle;
	}
	public Boolean getIsnew() {
		return isnew;
	}
	public void setIsnew(Boolean isnew) {
		this.isnew = isnew;
	}
	public Boolean getIsrecommand() {
		return isrecommand;
	}
	public void setIsrecommand(Boolean isrecommand) {
		this.isrecommand = isrecommand;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public Integer getFenQuNum() {
		return fenQuNum;
	}
	public void setFenQuNum(Integer fenQuNum) {
		this.fenQuNum = fenQuNum;
	}
	public String getFenQuName() {
		return fenQuName;
	}
	public void setFenQuName(String fenQuName) {
		this.fenQuName = fenQuName;
	}
	public String getServerId() {
		return serverId;
	}
	public void setServerId(String serverId) {
		this.serverId = serverId;
	}
	public String getServerName() {
		return serverName;
	}
	public void setServerName(String serverName) {
		this.serverName = serverName;
	}
	public String getOpenStatus() {
		return openStatus;
	}
	public void setOpenStatus(String openStatus) {
		this.openStatus = openStatus;
	}
	public String getOpenTime() {
		return openTime;
	}
	public void setOpenTime(String openTime) {
		this.openTime = openTime;
	}
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}
	public String getAddress() {
		return address;
	}
	public void setAddress(String address) {
		this.address = address;
	}
	public String getFenQuNickName() {
		return fenQuNickName;
	}
	public void setFenQuNickName(String fenQuNickName) {
		this.fenQuNickName = fenQuNickName;
	}
	public String getFromopentime() {
		return fromopentime;
	}
	public void setFromopentime(String fromopentime) {
		this.fromopentime = fromopentime;
	}
	public String getToopentime() {
		return toopentime;
	}
	public void setToopentime(String toopentime) {
		this.toopentime = toopentime;
	}
	
}

==> xlniuxdata-vipgame-1.0.43-20160125.081729-9-sources.jar: com/xunlei/niux/data/vipgame/vo/GameServers.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;

/**
 * 游戏服务器（分区）
 * @author lin
 * @date 2012-9-12
 * @Descripter:
 */
@Table(tableName="gameservers",pkFieldName="seqId",pkFieldAssign=false)
public class GameServers {
	private Long seqId;
	private String gameId;
	private Integer fenQuNum;
	private String fenQuName;
	private String serverId;
	private String serverName;
	private String openStatus;
	private String openTime;
	private String remark;
	private String inputBy;
	private String inputTime;
	private String editBy;
	private String editTime;
	private String address;
	private Boolean redtitle;
	private Boolean isnew;
	private Boolean isrecommand;
	private String fenQuNickName;
	private String bigFenQuName;
	@Column(columnName="openTime",isWhereColumn=true,operator=Operator.GE)
	private String fromopentime;
	@Column(columnName="openTime",isWhereColumn=true,operator=Operator.LT)
	private String toopentime;
	
	private Integer fenQuOpenFlag;
	private String fenQuOpenTime;
	
	public String getBigFenQuName() {
		return bigFenQuName;
	}
	public void setBigFenQuName(String bigFenQuName) {
		this.bigFenQuName = bigFenQuName;
	}
	public Boolean getRedtitle() {
		return redtitle;
	}
	public void setRedtitle(Boolean redtitle) {
		this.redtitle = redtitle;
	}
	public Boolean getIsnew() {
		return isnew;
	}
	public void setIsnew(Boolean isnew) {
		this.isnew = isnew;
	}
	public Boolean getIsrecommand() {
		return isrecommand;
	}
	public void setIsrecommand(Boolean isrecommand) {
		this.isrecommand = isrecommand;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public Integer getFenQuNum() {
		return fenQuNum;
	}
	public void setFenQuNum(Integer fenQuNum) {
		this.fenQuNum = fenQuNum;
	}
	public String getFenQuName() {
		return fenQuName;
	}
	public void setFenQuName(String fenQuName) {
		this.fenQuName = fenQuName;
	}
	public String getServerId() {
		return serverId;
	}
	public void setServerId(String serverId) {
		this.serverId = serverId;
	}
	public String getServerName() {
		return serverName;
	}
	public void setServerName(String serverName) {
		this.serverName = serverName;
	}
	public String getOpenStatus() {
		return openStatus;
	}
	public void setOpenStatus(String openStatus) {
		this.openStatus = openStatus;
	}
	public String getOpenTime() {
		return openTime;
	}
	public void setOpenTime(String openTime) {
		this.openTime = openTime;
	}
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}
	public String getAddress() {
		return address;
	}
	public void setAddress(String address) {
		this.address = address;
	}
	public String getFenQuNickName() {
		return fenQuNickName;
	}
	public void setFenQuNickName(String fenQuNickName) {
		this.fenQuNickName = fenQuNickName;
	}
	public String getFromopentime() {
		return fromopentime;
	}
	public void setFromopentime(String fromopentime) {
		this.fromopentime = fromopentime;
	}
	public String getToopentime() {
		return toopentime;
	}
	public void setToopentime(String toopentime) {
		this.toopentime = toopentime;
	}
	
	public Integer getFenQuOpenFlag() {
		return fenQuOpenFlag;
	}
	public void setFenQuOpenFlag(Integer fenQuOpenFlag) {
		this.fenQuOpenFlag = fenQuOpenFlag;
	}
	public String getFenQuOpenTime() {
		return fenQuOpenTime;
	}
	public void setFenQuOpenTime(String fenQuOpenTime) {
		this.fenQuOpenTime = fenQuOpenTime;
	}
	
}
